from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='inkpot',
    version='0.1.0',
    description='a small simple library for generating documentation from docstrings',
    url='https://github.com/AxelGard/inkpot',
    author='Axel Gard',
    author_email='axel.gard@tutanota.com',
    license='MIT',
    packages=['inkpot'],
    long_description=long_description,
    long_description_content_type="text/markdown",

    install_requires=[],


    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Documentation",
        "License :: OSI Approved :: MIT License",
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)



import sys


def main():
    flag = False
    last_func = ""
    table = {}
    with open(sys.argv[1], 'r') as file:
        for cnt, line in enumerate(file):
            #print("Line {}: {}".format(cnt, line))
            if "def" in line:
                func = line.replace("def ", '')
                func = func.replace('\n', '')
                func = func.replace(':', '')
                table[func] = ""
                last_func = func
                flag = True
            elif flag:
                doc = line.replace('\n', '')
                doc = doc.replace('  ', '')
                doc = doc.replace('"""', '')
                table[last_func] = doc
                flag = False


    for func in table.keys():
        print(f"| %s |%s|" %(func, table[func]))




if __name__ == "__main__":
    main()
